@@ -2,7 +2,7 @@ import os
 from os.path import join
 import posixpath
 import shutil
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
 from .download import download_and_extract_zip
 from .pyproject_configs import Download, StaticLibConfig
@@ -12,6 +12,7 @@ class StaticLib:
     # implements pkgcfg
 
     def __init__(self, name: str, cfg: StaticLibConfig, setup):
+        self.package_name = name
         self.name = name
         self.cfg = cfg
         self.static_lib = True
@@ -61,7 +62,7 @@ class StaticLib:
 
         return [join(self.libdir, lib) for lib in self._get_libnames()]
 
-    def get_type_casters(self, casters: Dict[str, str]) -> None:
+    def get_type_casters_cfg(self, casters: Dict[str, Dict[str, Any]]) -> None:
         pass
 
     def _get_dl_libnames(self, dl: Download, useext=True):
@@ -78,7 +79,6 @@ class StaticLib:
         return libs
 
     def on_build_dl(self, cache: str, libdir: str):
-
         self.set_root(libdir)
 
         shutil.rmtree(self.libdir, ignore_errors=True)
@@ -87,7 +87,6 @@ class StaticLib:
         os.makedirs(self.libdir)
 
         for dl in self.cfg.download:
-
             if dl.sources is not None:
                 raise ValueError(f"{dl.url}: cannot specify sources in static lib")
 
