@@ -12,6 +12,8 @@ int fnOverload(int i)
 
 struct OverloadedObject
 {
+    using z = int;
+
     int overloaded(int i)
     {
         return 0x1;
@@ -20,6 +22,12 @@ struct OverloadedObject
     {
         return 0x2;
     }
+    // Hack: this tricks CppHeaderParser..
+    const z& overloaded(int i, int j)
+    {
+        o = i + j;
+        return o;
+    }
 
     constexpr int overloaded_constexpr(int a, int b) {
         return a + b;
@@ -37,4 +45,7 @@ struct OverloadedObject
     {
         return 0x4;
     }
+
+private:
+    int o;
 };
\ No newline at end of file
